
dlnpyutils
==========

A package of useful utility python functions.

Authors
-------

- **David Nidever** (Montana State University)
  
Installation
------------

You can pip install the package::

    pip install dlnpyutils

To install the latest version::

    pip install git+https://github.com/dnidever/dlnpyutils

Attribution
-----------

.. image:: https://zenodo.org/badge/205585866.svg
   :target: https://zenodo.org/badge/latestdoi/205585866

If you make use of this code, please cite this work using the DOI::

    Nidever, D. L. 2021, dnidever/dlnpyutils, doi:10.5281/zenodo.5764938

    
    
Documentation
-------------

.. image:: https://readthedocs.org/projects/dlnpyutils/badge/?version=latest
        :target: http://dlnpyutils.readthedocs.io/

See `the documentation <http://dlnpyutils.readthedocs.io>`_ for information on how
to install and use dlnpyutils.

License
-------

.. image:: http://img.shields.io/badge/license-GNU-blue.svg?style=flat
        :target: https://github.com/dnidever/doppler/blob/main/LICENSE
